/* ###
 * IP: GHIDRA
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package agent.dbgmodel.jna.dbgmodel.datamodel.script.debug;

import com.sun.jna.Pointer;
import com.sun.jna.WString;
import com.sun.jna.platform.win32.Guid.IID;
import com.sun.jna.platform.win32.WTypes.BSTRByReference;
import com.sun.jna.platform.win32.WinDef.BOOLByReference;
import com.sun.jna.platform.win32.WinNT.HRESULT;
import com.sun.jna.ptr.PointerByReference;

import agent.dbgmodel.jna.dbgmodel.IUnknownEx;
import agent.dbgmodel.jna.dbgmodel.UnknownWithUtils.VTableIndex;

public interface IDataModelScriptDebugStackFrame extends IUnknownEx {
	final IID IID_IDATA_MODEL_SCRIPT_DEBUG_STACK_FRAME =
		new IID("DEC6ED5E-6360-4941-AB4C-A26409DE4F82");

	enum VTIndices implements VTableIndex {
		GET_NAME, //
		GET_POSITION, //
		IS_TRANSITION_POINT, //
		GET_TRANSITION, //
		EVALUATE, //
		ENUMERATE_LOCALS, //
		ENUMERATE_ARGUMENTS, //	
		;

		static int start = 3;

		@Override
		public int getIndex() {
			return this.ordinal() + start;
		}
	}

	HRESULT GetName(BSTRByReference name);

	HRESULT GetPosition(Pointer position, Pointer positionSpanEnd, BSTRByReference lineText);

	HRESULT IsTransitionPoint(BOOLByReference isTransitionPoint);

	HRESULT GetTransition(PointerByReference transitionScript,
			BOOLByReference isTransitionContiguous);

	HRESULT Evaluate(WString pwszExpression, PointerByReference ppResult);

	HRESULT EnumerateLocals(PointerByReference variablesEnum);

	HRESULT EnumerateArguments(PointerByReference variablesEnum);

}
