/* ###
 * IP: GHIDRA
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ghidra.trace.database.target;

import ghidra.trace.model.Lifespan;

interface TraceObjectValueStorage {
	DBTraceObjectManager getManager();

	DBTraceObjectValue getWrapper();

	DBTraceObject getParent();

	String getEntryKey();

	/**
	 * Just set the lifespan, no notifications
	 * 
	 * <p>
	 * The wrapper will notify the parent and child, if necessary.
	 * 
	 * @param lifespan the new lifespan
	 */
	void doSetLifespan(Lifespan lifespan);

	Lifespan getLifespan();

	DBTraceObject getChildOrNull();

	Object getValue();

	boolean isDeleted();

	void doDelete();
}
